==> runtime-3.0.75-sources.jar: com/cloudimpl/outstack/runtime/domain/PolicyRefCreated.java <==
/*
 * Copyright 2021 nuwan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudimpl.outstack.runtime.domain;

import com.cloudimpl.outstack.runtime.domainspec.Entity;
import com.cloudimpl.outstack.runtime.domainspec.Event;
import com.cloudimpl.outstack.runtime.domainspec.RootEntity;

/**
 *
 * @author nuwan
 */
public class PolicyRefCreated extends Event<PolicyRef>{
    private final String policyRef;
    private final String roleName;
    public PolicyRefCreated(String roleName,String policyRef) {
        this.roleName = roleName;
        this.policyRef = policyRef;
    }
    
    @Override
    public Class<? extends Entity> getOwner() {
        return PolicyRef.class;
    }

    @Override
    public Class<? extends RootEntity> getRootOwner() {
        return Role.class;
    }

    @Override
    public String entityId() {
        return policyRef;
    }

    @Override
    public String rootEntityId() {
        return roleName;
    }

    public String getPolicyRef() {
        return policyRef;
    }
    
    
}

==> runtime-3.0.232-sources.jar: com/cloudimpl/outstack/runtime/domain/PolicyRefCreated.java <==
/*
 * Copyright 2021 nuwan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudimpl.outstack.runtime.domain;

import com.cloudimpl.outstack.runtime.domainspec.Entity;
import com.cloudimpl.outstack.runtime.domainspec.Event;
import com.cloudimpl.outstack.runtime.domainspec.RootEntity;

/**
 *
 * @author nuwan
 */
public class PolicyRefCreated extends Event<PolicyRef>{
    private final String policyRef;
    private final String roleName;
    private final String version;
    private final String domainContext;
    private final String domainOwner;
    public PolicyRefCreated(String domainOwner,String domainContext,String version,String roleName,String policyRef) {
        this.roleName = roleName;
        this.policyRef = policyRef;
        this.version = version;
        this.domainContext = domainContext;
        this.domainOwner = domainOwner;
    }
    
    @Override
    public Class<? extends Entity> getOwner() {
        return PolicyRef.class;
    }

    @Override
    public Class<? extends RootEntity> getRootOwner() {
        return Role.class;
    }

    @Override
    public String entityId() {
        return policyRef;
    }

    public String getVersion() {
        return version;
    }

    @Override
    public String rootEntityId() {
        return roleName;
    }

    public String getPolicyRef() {
        return policyRef;
    }

    public String getDomainOwner() {
        return domainOwner;
    }

    public String getDomainContext() {
        return domainContext;
    }
    
}
